summaryrefslogtreecommitdiffstats
path: root/src/prefpreview.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /src/prefpreview.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/prefpreview.cpp')
-rw-r--r--src/prefpreview.cpp110
1 files changed, 55 insertions, 55 deletions
diff --git a/src/prefpreview.cpp b/src/prefpreview.cpp
index 54a959e..cb2fad6 100644
--- a/src/prefpreview.cpp
+++ b/src/prefpreview.cpp
@@ -9,101 +9,101 @@
#include "prefpreview.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qbuttongroup.h>
-#include <qradiobutton.h>
-#include <qwidgetstack.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqbuttongroup.h>
+#include <tqradiobutton.h>
+#include <tqwidgetstack.h>
+#include <tqlabel.h>
+#include <tqcheckbox.h>
+#include <tqcombobox.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
/*
* Constructs a prefPreview as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-prefPreview::prefPreview( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+prefPreview::prefPreview( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "prefPreview" );
- prefPreviewLayout = new QGridLayout( this, 1, 1, 11, 6, "prefPreviewLayout");
+ prefPreviewLayout = new TQGridLayout( this, 1, 1, 11, 6, "prefPreviewLayout");
- buttonGroup1 = new QButtonGroup( this, "buttonGroup1" );
- buttonGroup1->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, buttonGroup1->sizePolicy().hasHeightForWidth() ) );
- buttonGroup1->setFrameShape( QButtonGroup::NoFrame );
+ buttonGroup1 = new TQButtonGroup( this, "buttonGroup1" );
+ buttonGroup1->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, buttonGroup1->sizePolicy().hasHeightForWidth() ) );
+ buttonGroup1->setFrameShape( TQButtonGroup::NoFrame );
buttonGroup1->setColumnLayout(0, Qt::Vertical );
- buttonGroup1->layout()->setSpacing( 6 );
- buttonGroup1->layout()->setMargin( 11 );
- buttonGroup1Layout = new QGridLayout( buttonGroup1->layout() );
- buttonGroup1Layout->setAlignment( Qt::AlignTop );
+ buttonGroup1->tqlayout()->setSpacing( 6 );
+ buttonGroup1->tqlayout()->setMargin( 11 );
+ buttonGroup1Layout = new TQGridLayout( buttonGroup1->tqlayout() );
+ buttonGroup1Layout->tqsetAlignment( TQt::AlignTop );
- rbInternal = new QRadioButton( buttonGroup1, "rbInternal" );
+ rbInternal = new TQRadioButton( buttonGroup1, "rbInternal" );
buttonGroup1Layout->addWidget( rbInternal, 0, 0 );
- rbMplayer = new QRadioButton( buttonGroup1, "rbMplayer" );
+ rbMplayer = new TQRadioButton( buttonGroup1, "rbMplayer" );
buttonGroup1Layout->addWidget( rbMplayer, 1, 0 );
prefPreviewLayout->addWidget( buttonGroup1, 0, 0 );
- spacer5 = new QSpacerItem( 21, 210, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer5 = new TQSpacerItem( 21, 210, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
prefPreviewLayout->addItem( spacer5, 2, 0 );
- wsOptions = new QWidgetStack( this, "wsOptions" );
- wsOptions->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, wsOptions->sizePolicy().hasHeightForWidth() ) );
- wsOptions->setFrameShape( QWidgetStack::NoFrame );
- wsOptions->setFrameShadow( QWidgetStack::Sunken );
+ wsOptions = new TQWidgetStack( this, "wsOptions" );
+ wsOptions->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, wsOptions->sizePolicy().hasHeightForWidth() ) );
+ wsOptions->setFrameShape( TQWidgetStack::NoFrame );
+ wsOptions->setFrameShadow( TQWidgetStack::Sunken );
wsOptions->setLineWidth( 1 );
wsOptions->setMidLineWidth( 0 );
- wspInternal = new QWidget( wsOptions, "wspInternal" );
- wspInternalLayout = new QGridLayout( wspInternal, 1, 1, 11, 6, "wspInternalLayout");
+ wspInternal = new TQWidget( wsOptions, "wspInternal" );
+ wspInternalLayout = new TQGridLayout( wspInternal, 1, 1, 11, 6, "wspInternalLayout");
- textLabel1 = new QLabel( wspInternal, "textLabel1" );
- QFont textLabel1_font( textLabel1->font() );
+ textLabel1 = new TQLabel( wspInternal, "textLabel1" );
+ TQFont textLabel1_font( textLabel1->font() );
textLabel1_font.setBold( TRUE );
textLabel1->setFont( textLabel1_font );
wspInternalLayout->addWidget( textLabel1, 0, 0 );
- ckUseGL = new QCheckBox( wspInternal, "ckUseGL" );
+ ckUseGL = new TQCheckBox( wspInternal, "ckUseGL" );
wspInternalLayout->addWidget( ckUseGL, 1, 0 );
- spacer1 = new QSpacerItem( 21, 30, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer1 = new TQSpacerItem( 21, 30, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
wspInternalLayout->addItem( spacer1, 2, 0 );
wsOptions->addWidget( wspInternal, 0 );
- wspMplayer = new QWidget( wsOptions, "wspMplayer" );
- wspMplayerLayout = new QGridLayout( wspMplayer, 1, 1, 11, 6, "wspMplayerLayout");
+ wspMplayer = new TQWidget( wsOptions, "wspMplayer" );
+ wspMplayerLayout = new TQGridLayout( wspMplayer, 1, 1, 11, 6, "wspMplayerLayout");
- textLabel3 = new QLabel( wspMplayer, "textLabel3" );
+ textLabel3 = new TQLabel( wspMplayer, "textLabel3" );
wspMplayerLayout->addWidget( textLabel3, 1, 0 );
- textLabel4 = new QLabel( wspMplayer, "textLabel4" );
- textLabel4->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, textLabel4->sizePolicy().hasHeightForWidth() ) );
+ textLabel4 = new TQLabel( wspMplayer, "textLabel4" );
+ textLabel4->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, textLabel4->sizePolicy().hasHeightForWidth() ) );
wspMplayerLayout->addWidget( textLabel4, 2, 0 );
- cbVout = new QComboBox( FALSE, wspMplayer, "cbVout" );
+ cbVout = new TQComboBox( FALSE, wspMplayer, "cbVout" );
wspMplayerLayout->addWidget( cbVout, 1, 1 );
- cbAout = new QComboBox( FALSE, wspMplayer, "cbAout" );
- cbAout->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)0, 0, 0, cbAout->sizePolicy().hasHeightForWidth() ) );
+ cbAout = new TQComboBox( FALSE, wspMplayer, "cbAout" );
+ cbAout->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)0, 0, 0, cbAout->sizePolicy().hasHeightForWidth() ) );
wspMplayerLayout->addWidget( cbAout, 2, 1 );
- spacer3 = new QSpacerItem( 81, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer3 = new TQSpacerItem( 81, 21, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
wspMplayerLayout->addItem( spacer3, 1, 2 );
- spacer6 = new QSpacerItem( 20, 21, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer6 = new TQSpacerItem( 20, 21, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
wspMplayerLayout->addItem( spacer6, 3, 1 );
- textLabel2 = new QLabel( wspMplayer, "textLabel2" );
- QFont textLabel2_font( textLabel2->font() );
+ textLabel2 = new TQLabel( wspMplayer, "textLabel2" );
+ TQFont textLabel2_font( textLabel2->font() );
textLabel2_font.setBold( TRUE );
textLabel2->setFont( textLabel2_font );
@@ -111,15 +111,15 @@ prefPreview::prefPreview( QWidget* parent, const char* name, WFlags fl )
wsOptions->addWidget( wspMplayer, 1 );
prefPreviewLayout->addWidget( wsOptions, 1, 0 );
- spacer4 = new QSpacerItem( 230, 21, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer4 = new TQSpacerItem( 230, 21, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
prefPreviewLayout->addItem( spacer4, 0, 1 );
languageChange();
- resize( QSize(536, 470).expandedTo(minimumSizeHint()) );
+ resize( TQSize(536, 470).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( rbInternal, SIGNAL( clicked() ), this, SLOT( rbInternalClick() ) );
- connect( rbMplayer, SIGNAL( clicked() ), this, SLOT( rbMplayerClick() ) );
+ connect( rbInternal, TQT_SIGNAL( clicked() ), this, TQT_SLOT( rbInternalClick() ) );
+ connect( rbMplayer, TQT_SIGNAL( clicked() ), this, TQT_SLOT( rbMplayerClick() ) );
}
/*
@@ -127,7 +127,7 @@ prefPreview::prefPreview( QWidget* parent, const char* name, WFlags fl )
*/
prefPreview::~prefPreview()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -137,11 +137,11 @@ prefPreview::~prefPreview()
void prefPreview::languageChange()
{
setCaption( tr2i18n( "Form1" ) );
- buttonGroup1->setTitle( QString::null );
+ buttonGroup1->setTitle( TQString() );
rbInternal->setText( tr2i18n( "&Internal Player" ) );
- rbInternal->setAccel( QKeySequence( tr2i18n( "Alt+I" ) ) );
+ rbInternal->setAccel( TQKeySequence( tr2i18n( "Alt+I" ) ) );
rbMplayer->setText( tr2i18n( "MPlayer" ) );
- rbMplayer->setAccel( QKeySequence( tr2i18n( "Alt+M" ) ) );
+ rbMplayer->setAccel( TQKeySequence( tr2i18n( "Alt+M" ) ) );
textLabel1->setText( tr2i18n( "Internal viewer options" ) );
ckUseGL->setText( tr2i18n( "use OpenGL" ) );
textLabel3->setText( tr2i18n( "Video output" ) );
@@ -9,101 +9,101 @@
/*
- * Constructs a prefPreview as a child of 'parent', with the
+ * Constructs a prefPreview as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -127,7 +127,7 @@ prefPreview::prefPreview( QWidget* parent, const char* name, WFlags fl )
prefPreview::~prefPreview()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*